summaryrefslogtreecommitdiffstats
path: root/kexi/widget/utils/kexiflowlayout.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/widget/utils/kexiflowlayout.h')
-rw-r--r--kexi/widget/utils/kexiflowlayout.h52
1 files changed, 28 insertions, 24 deletions
diff --git a/kexi/widget/utils/kexiflowlayout.h b/kexi/widget/utils/kexiflowlayout.h
index 173ddad5..e410fb83 100644
--- a/kexi/widget/utils/kexiflowlayout.h
+++ b/kexi/widget/utils/kexiflowlayout.h
@@ -20,27 +20,27 @@
#ifndef KEXIFLOWLAYOUT_H
#define KEXIFLOWLAYOUT_H
-#include <qlayout.h>
-#include <qptrlist.h>
+#include <tqlayout.h>
+#include <tqptrlist.h>
-//! @short a special "flow" layout
-class KEXIGUIUTILS_EXPORT KexiFlowLayout : public QLayout
+//! @short a special "flow" tqlayout
+class KEXIGUIUTILS_EXPORT KexiFlowLayout : public TQLayout
{
public:
- KexiFlowLayout(QWidget *parent, int border=0, int space=-1, const char *name=0);
- KexiFlowLayout(QLayout* parent, int space=-1, const char *name=0);
+ KexiFlowLayout(TQWidget *tqparent, int border=0, int space=-1, const char *name=0);
+ KexiFlowLayout(TQLayout* tqparent, int space=-1, const char *name=0);
KexiFlowLayout(int space=-1, const char *name=0);
~KexiFlowLayout();
/*! \return the widgets in the order of the layout,
ie as it is stored in m_list. You must delete the list after using it. */
- QPtrList<QWidget>* widgetList() const;
+ TQPtrList<TQWidget>* widgetList() const;
- /*! Sets layout's orientation to \a orientation. Default orientation is Vertical. */
- void setOrientation(Orientation orientation) { m_orientation = orientation; }
+ /*! Sets tqlayout's orientation to \a orientation. Default orientation isQt::Vertical. */
+ void setOrientation(Qt::Orientation orientation) { m_orientation = orientation; }
- /*! \return layout's orientation. */
+ /*! \return tqlayout's orientation. */
Qt::Orientation orientation() const { return m_orientation; }
void setJustified(bool justify) { m_justify = justify; }
@@ -48,31 +48,35 @@ class KEXIGUIUTILS_EXPORT KexiFlowLayout : public QLayout
virtual void addItem(QLayoutItem *item);
virtual void addSpacing(int size);
- virtual QLayoutIterator iterator();
- virtual void invalidate();
+ virtual TQLayoutIterator iterator();
+ virtual void tqinvalidate();
virtual bool hasHeightForWidth() const;
virtual int heightForWidth(int width) const;
- virtual QSize sizeHint() const;
- virtual QSize minimumSize() const;
- virtual QSizePolicy::ExpandData expanding() const;
+ virtual TQSize tqsizeHint() const;
+ virtual TQSize tqminimumSize() const;
+ virtual TQSizePolicy::ExpandData expanding() const;
virtual bool isEmpty();
+#ifdef USE_QT4
+ QLAYOUT_REQUIRED_METHOD_DECLARATIONS
+#endif // USE_QT4
+
protected:
- virtual void setGeometry(const QRect&);
- int simulateLayout(const QRect &r);
- int doHorizontalLayout(const QRect&, bool testonly = false);
- int doVerticalLayout(const QRect&, bool testonly = false);
+ virtual void setGeometry(const TQRect&);
+ int simulateLayout(const TQRect &r);
+ int doHorizontalLayout(const TQRect&, bool testonly = false);
+ int doVerticalLayout(const TQRect&, bool testonly = false);
private:
- QPtrList<QLayoutItem> m_list;
+ TQPtrList<TQLayoutItem> m_list;
int m_cached_width;
int m_cached_hfw;
bool m_justify;
- Orientation m_orientation;
- QSize m_cached_sizeHint;
- QSize m_cached_minSize;
+ Qt::Orientation m_orientation;
+ TQSize m_cached_tqsizeHint;
+ TQSize m_cached_minSize;
};
#endif
@@ -20,27 +20,27 @@
KexiFlowLayout(int space=-1, const char *name=0);
~KexiFlowLayout();
- /*! \return the widgets in the order of the layout,
+ /*! \return the widgets in the order of the tqlayout,
ie as it is stored in m_list. You must delete the list after using it. */